"use client"

import { useState } from "react"
import { motion } from "framer-motion"
import { useForm } from "react-hook-form"
import { zodResolver } from "@hookform/resolvers/zod"
import * as z from "zod"
import { Button } from "@/components/ui/button"
import { Input } from "@/components/ui/input"
import { Textarea } from "@/components/ui/textarea"
import { Form, FormControl, FormField, FormItem, FormLabel, FormMessage } from "@/components/ui/form"
import { Select, SelectContent, SelectItem, SelectTrigger, SelectValue } from "@/components/ui/select"
import { Card, CardContent, CardHeader, CardTitle } from "@/components/ui/card"

const formSchema = z.object({
  name: z.string().min(2, {
    message: "İsim en az 2 karakter olmalıdır.",
  }),
  email: z.string().email({
    message: "Geçerli bir e-posta adresi giriniz.",
  }),
  company: z.string().min(2, {
    message: "Şirket adı en az 2 karakter olmalıdır.",
  }),
  service: z.string({
    required_error: "Lütfen bir hizmet seçin.",
  }),
  message: z.string().min(10, {
    message: "Mesaj en az 10 karakter olmalıdır.",
  }),
})

export default function ContactForm() {
  const [isSubmitting, setIsSubmitting] = useState(false)
  const [isSuccess, setIsSuccess] = useState(false)

  const form = useForm<z.infer<typeof formSchema>>({
    resolver: zodResolver(formSchema),
    defaultValues: {
      name: "",
      email: "",
      company: "",
      message: "",
    },
  })

  function onSubmit(values: z.infer<typeof formSchema>) {
    setIsSubmitting(true)

    // Simulate API call
    setTimeout(() => {
      console.log(values)
      setIsSubmitting(false)
      setIsSuccess(true)
      form.reset()

      // Reset success message after 5 seconds
      setTimeout(() => setIsSuccess(false), 5000)
    }, 1500)
  }

  return (
    <section className="py-20 relative" id="contact">
      <div className="container relative z-10">
        <div className="text-center mb-16">
          <h2 className="text-4xl font-bold mb-4 golden-text">İletişime Geçin</h2>
          <p className="text-muted-foreground max-w-2xl mx-auto">
            Yapay zeka destekli çözümlerimiz hakkında daha fazla bilgi almak için formu doldurun, size en kısa sürede
            dönüş yapalım.
          </p>
        </div>

        <motion.div
          initial={{ opacity: 0, y: 20 }}
          whileInView={{ opacity: 1, y: 0 }}
          viewport={{ once: true }}
          transition={{ duration: 0.5 }}
          className="max-w-2xl mx-auto"
        >
          <Card className="glass-card neon-border">
            <CardHeader>
              <CardTitle className="text-white">İletişim Formu</CardTitle>
            </CardHeader>
            <CardContent>
              {isSuccess ? (
                <div className="bg-green-900/30 border border-green-500/30 text-green-400 px-4 py-3 rounded relative mb-4">
                  <strong className="font-bold">Teşekkürler!</strong>
                  <span className="block sm:inline">
                    {" "}
                    Mesajınız başarıyla gönderildi. En kısa sürede size dönüş yapacağız.
                  </span>
                </div>
              ) : (
                <Form {...form}>
                  <form onSubmit={form.handleSubmit(onSubmit)} className="space-y-6">
                    <FormField
                      control={form.control}
                      name="name"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel className="text-gray-300">İsim Soyisim</FormLabel>
                          <FormControl>
                            <Input
                              placeholder="Adınız Soyadınız"
                              {...field}
                              className="bg-background/50 border-white/10 focus:border-primary/50"
                            />
                          </FormControl>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                    <FormField
                      control={form.control}
                      name="email"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel className="text-gray-300">E-posta</FormLabel>
                          <FormControl>
                            <Input
                              placeholder="ornek@sirket.com"
                              {...field}
                              className="bg-background/50 border-white/10 focus:border-primary/50"
                            />
                          </FormControl>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                    <FormField
                      control={form.control}
                      name="company"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel className="text-gray-300">Şirket</FormLabel>
                          <FormControl>
                            <Input
                              placeholder="Şirketinizin adı"
                              {...field}
                              className="bg-background/50 border-white/10 focus:border-primary/50"
                            />
                          </FormControl>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                    <FormField
                      control={form.control}
                      name="service"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel className="text-gray-300">İlgilendiğiniz Hizmet</FormLabel>
                          <Select onValueChange={field.onChange} defaultValue={field.value}>
                            <FormControl>
                              <SelectTrigger className="bg-background/50 border-white/10 focus:border-primary/50">
                                <SelectValue placeholder="Bir hizmet seçin" />
                              </SelectTrigger>
                            </FormControl>
                            <SelectContent className="bg-background border-white/10">
                              <SelectItem value="digital-marketing">Yapay Zeka Destekli Dijital Pazarlama</SelectItem>
                              <SelectItem value="chatbot">AI Chatbot ve Müşteri Hizmetleri Otomasyonu</SelectItem>
                              <SelectItem value="sector-solutions">Sektör Bazlı Yapay Zeka Çözümleri</SelectItem>
                              <SelectItem value="other">Diğer</SelectItem>
                            </SelectContent>
                          </Select>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                    <FormField
                      control={form.control}
                      name="message"
                      render={({ field }) => (
                        <FormItem>
                          <FormLabel className="text-gray-300">Mesajınız</FormLabel>
                          <FormControl>
                            <Textarea
                              placeholder="Nasıl yardımcı olabiliriz?"
                              className="min-h-[120px] bg-background/50 border-white/10 focus:border-primary/50"
                              {...field}
                            />
                          </FormControl>
                          <FormMessage />
                        </FormItem>
                      )}
                    />
                    <Button
                      type="submit"
                      className="w-full bg-primary hover:bg-primary/90 animated-border"
                      disabled={isSubmitting}
                    >
                      {isSubmitting ? "Gönderiliyor..." : "Gönder"}
                    </Button>
                  </form>
                </Form>
              )}
            </CardContent>
          </Card>
        </motion.div>
      </div>
    </section>
  )
}

